aboutsummaryrefslogtreecommitdiffstats
path: root/wee_slack.py
diff options
context:
space:
mode:
authorRyan Huber <rhuber@gmail.com>2016-09-26 13:57:12 -0700
committerRyan Huber <rhuber@gmail.com>2016-09-26 13:57:12 -0700
commitdbeb8e8cfa4024665a6bb3708cfe016701b878fb (patch)
treee2d15b2f98b5f4eb41393008fb7a2ac5e60985c0 /wee_slack.py
parentf2027aa32da094497ffb4af0f926f167cff7e3fb (diff)
downloadwee-slack-dbeb8e8cfa4024665a6bb3708cfe016701b878fb.tar.gz
longer timeout, because big teams
Diffstat (limited to 'wee_slack.py')
-rw-r--r--wee_slack.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/wee_slack.py b/wee_slack.py
index ac2b57a..65793fc 100644
--- a/wee_slack.py
+++ b/wee_slack.py
@@ -210,9 +210,9 @@ class SlackServer(object):
def should_connect(self):
"""
If we haven't tried to connect OR we tried and never heard back and it
has been 65 seconds consider the attempt dead and try again
"""
- if self.connection_attempt_time == 0 or self.connection_attempt_time + 65 > int(time.time()):
+ if self.connection_attempt_time == 0 or self.connection_attempt_time + 125 > int(time.time()):
return True
else:
return False
@@ -210,9 +210,9 @@ class SlackServer(object):
"""
If we haven't tried to connect OR we tried and never heard back and it
- has been 65 seconds consider the attempt dead and try again
+ has been 125 seconds consider the attempt dead and try again
"""